@@ -13,6 +13,8 @@ pub mod rand;
 pub mod state;
 pub mod stats;
 pub mod tcp_type;
+pub mod udp_mux;
+pub mod udp_network;
 pub mod url;
 pub mod use_candidate;
 mod util;
